Index: src/wp-admin/css/forms.css
===================================================================
--- src/wp-admin/css/forms.css	(revision 49966)
+++ src/wp-admin/css/forms.css	(working copy)
@@ -1330,13 +1330,6 @@
 	margin: 1.5em 0;
 }
 
-.wp-privacy-request-form label {
-	font-weight: 600;
-	line-height: 1.5;
-	padding-bottom: .5em;
-	display: block;
-}
-
 .wp-privacy-request-form input {
 	margin: 0;
 }
Index: src/wp-admin/erase-personal-data.php
===================================================================
--- src/wp-admin/erase-personal-data.php	(revision 49966)
+++ src/wp-admin/erase-personal-data.php	(working copy)
@@ -58,12 +58,31 @@
 
 	<form action="<?php echo esc_url( admin_url( 'erase-personal-data.php' ) ); ?>" method="post" class="wp-privacy-request-form">
 		<h2><?php esc_html_e( 'Add Data Erasure Request' ); ?></h2>
-		<p><?php esc_html_e( 'An email will be sent to the user at this email address asking them to verify the request.' ); ?></p>
-
 		<div class="wp-privacy-request-form-field">
-			<label for="username_or_email_for_privacy_request"><?php esc_html_e( 'Username or email address' ); ?></label>
-			<input type="text" required class="regular-text ltr" id="username_or_email_for_privacy_request" name="username_or_email_for_privacy_request" />
-			<?php submit_button( __( 'Send Request' ), 'secondary', 'submit', false ); ?>
+			<table class="form-table">
+				<tr>
+					<th scope="row">
+						<label for="username_or_email_for_privacy_request"><?php esc_html_e( 'Username or email address' ); ?></label>
+					</th>
+					<td>
+						<input type="text" required class="regular-text ltr" id="username_or_email_for_privacy_request" name="username_or_email_for_privacy_request" />
+					</td>
+				</tr>
+				<tr>
+					<th scope="row">
+						<?php _e( 'Confirmation email' ); ?>
+					</th>
+					<td>
+						<label for="send_confirmation_email">
+							<input type="checkbox" name="send_confirmation_email" id="send_confirmation_email" value="1" checked="checked" />
+							<?php _e( 'Send personal data erasure confirmation email.' ); ?>
+						</label>
+					</td>
+				</tr>
+			</table>
+			<p class="submit">
+				<?php submit_button( __( 'Send Request' ), 'secondary', 'submit', false ); ?>
+			</p>
 		</div>
 		<?php wp_nonce_field( 'personal-data-request' ); ?>
 		<input type="hidden" name="action" value="add_remove_personal_data_request" />
Index: src/wp-admin/export-personal-data.php
===================================================================
--- src/wp-admin/export-personal-data.php	(revision 49966)
+++ src/wp-admin/export-personal-data.php	(working copy)
@@ -58,12 +58,31 @@
 
 	<form action="<?php echo esc_url( admin_url( 'export-personal-data.php' ) ); ?>" method="post" class="wp-privacy-request-form">
 		<h2><?php esc_html_e( 'Add Data Export Request' ); ?></h2>
-		<p><?php esc_html_e( 'An email will be sent to the user at this email address asking them to verify the request.' ); ?></p>
-
 		<div class="wp-privacy-request-form-field">
-			<label for="username_or_email_for_privacy_request"><?php esc_html_e( 'Username or email address' ); ?></label>
-			<input type="text" required class="regular-text ltr" id="username_or_email_for_privacy_request" name="username_or_email_for_privacy_request" />
-			<?php submit_button( __( 'Send Request' ), 'secondary', 'submit', false ); ?>
+		<table class="form-table">
+				<tr>
+					<th scope="row">
+						<label for="username_or_email_for_privacy_request"><?php esc_html_e( 'Username or email address' ); ?></label>
+					</th>
+					<td>
+						<input type="text" required class="regular-text ltr" id="username_or_email_for_privacy_request" name="username_or_email_for_privacy_request" />
+					</td>
+				</tr>
+				<tr>
+					<th scope="row">
+						<?php _e( 'Confirmation email' ); ?>
+					</th>
+					<td>
+						<label for="send_confirmation_email">
+							<input type="checkbox" name="send_confirmation_email" id="send_confirmation_email" value="1" checked="checked" />
+							<?php _e( 'Send personal data export confirmation email.' ); ?>
+						</label>
+					</td>
+				</tr>
+			</table>
+			<p class="submit">
+				<?php submit_button( __( 'Send Request' ), 'secondary', 'submit', false ); ?>
+			</p>
 		</div>
 		<?php wp_nonce_field( 'personal-data-request' ); ?>
 		<input type="hidden" name="action" value="add_export_personal_data_request" />
Index: src/wp-admin/includes/privacy-tools.php
===================================================================
--- src/wp-admin/includes/privacy-tools.php	(revision 49966)
+++ src/wp-admin/includes/privacy-tools.php	(working copy)
@@ -54,6 +54,10 @@
 
 	update_post_meta( $request_id, '_wp_user_request_completed_timestamp', time() );
 
+	if ( get_post_status( $request_id ) === 'request-skipped' ) {
+		return;
+	}
+
 	$result = wp_update_post(
 		array(
 			'ID'          => $request_id,
@@ -111,7 +115,12 @@
 				$action_type               = sanitize_text_field( wp_unslash( $_POST['type_of_action'] ) );
 				$username_or_email_address = sanitize_text_field( wp_unslash( $_POST['username_or_email_for_privacy_request'] ) );
 				$email_address             = '';
+				$send_confirmation_email   = true;
 
+				if ( ! isset( $_POST['send_confirmation_email'] ) ) {
+					$send_confirmation_email   = false;
+				}
+
 				if ( ! in_array( $action_type, _wp_privacy_action_request_types(), true ) ) {
 					add_settings_error(
 						'action_type',
@@ -141,7 +150,7 @@
 					break;
 				}
 
-				$request_id = wp_create_user_request( $email_address, $action_type );
+				$request_id = wp_create_user_request( $email_address, $action_type, array(), $send_confirmation_email );
 
 				if ( is_wp_error( $request_id ) ) {
 					add_settings_error(
@@ -161,7 +170,9 @@
 					break;
 				}
 
-				wp_send_user_request( $request_id );
+				if ( $send_confirmation_email ) {
+					wp_send_user_request( $request_id );
+				}
 
 				add_settings_error(
 					'username_or_email_for_privacy_request',
Index: src/wp-includes/user.php
===================================================================
--- src/wp-includes/user.php	(revision 49966)
+++ src/wp-includes/user.php	(working copy)
@@ -3770,12 +3770,13 @@
  *
  * @since 4.9.6
  *
  * @param string $email_address User email address. This can be the address of a registered or non-registered user.
  * @param string $action_name   Name of the action that is being confirmed. Required.
  * @param array  $request_data  Misc data you want to send with the verification request and pass to the actions once the request is confirmed.
  * @return int|WP_Error Returns the request ID if successful, or a WP_Error object on failure.
  */
-function wp_create_user_request( $email_address = '', $action_name = '', $request_data = array() ) {
+function wp_create_user_request( $email_address = '', $action_name = '', $request_data = array(), $send_confirmation_email = true ) {
 	$email_address = sanitize_email( $email_address );
 	$action_name   = sanitize_key( $action_name );
 
@@ -3808,6 +3809,12 @@
 		return new WP_Error( 'duplicate_request', __( 'An incomplete user privacy request for this email address already exists.' ) );
 	}
 
+	if ( $send_confirmation_email ) {
+		$status = 'request-pending';
+	} else {
+		$status = 'request-completed';
+	}
+
 	$request_id = wp_insert_post(
 		array(
 			'post_author'   => $user_id,
@@ -3814,7 +3821,7 @@
 			'post_name'     => $action_name,
 			'post_title'    => $email_address,
 			'post_content'  => wp_json_encode( $request_data ),
-			'post_status'   => 'request-pending',
+			'post_status'   => $status,
 			'post_type'     => 'user_request',
 			'post_date'     => current_time( 'mysql', false ),
 			'post_date_gmt' => current_time( 'mysql', true ),
@@ -3770,12 +3770,13 @@
  * @since 4.9.6
  *
- * @param string $email_address User email address. This can be the address of a registered or non-registered user.
- * @param string $action_name   Name of the action that is being confirmed. Required.
- * @param array  $request_data  Misc data you want to send with the verification request and pass to the actions once the request is confirmed.
- * @return int|WP_Error Returns the request ID if successful, or a WP_Error object on failure.
+ * @param string $email_address           User email address. This can be the address of a registered or non-registered user.
+ * @param string $action_name             Name of the action that is being confirmed. Required.
+ * @param array  $request_data            Misc data you want to send with the verification request and pass to the actions once the request is confirmed.
+ * @param bool   $send_confirmation_email Optional. True by default, if false is passed the request status is set to Completed directly.
+ * @return int|WP_Error                   Returns the request ID if successful, or a WP_Error object on failure.
  */
